@@ -17,7 +17,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.1.0';
+    $VERSION = '2.1.3';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
@@ -254,7 +254,9 @@ sub add_defaults {
         'cache options'                     => TRUE,
         cache                               => undef,
         'restore window'                    => TRUE,
-        'set_timestamp'                     => TRUE,
+        set_timestamp                       => TRUE,
+        use_time                            => FALSE,
+        use_timezone                        => TRUE,
         'date offset'                       => 0,
         'pdf compression'                   => 'auto',
         'tiff compression'                  => undef,
