@@ -268,7 +268,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::, signals => {
     ),
   ];
 
-our $VERSION = '2.1.0';
+our $VERSION = '2.1.3';
 
 my ( $d_sane, $logger );
 my $tolerance             = 1;
@@ -642,7 +642,7 @@ sub _save_profile_callback {
     my $entry = Gtk3::Entry->new;
     $entry->set_activates_default(TRUE);
     $hbox->pack_end( $entry, TRUE, TRUE, 0 );
-    $dialog->vbox->add($hbox);
+    $dialog->get_content_area->add($hbox);
     $dialog->set_default_response('ok');
     $dialog->show_all;
     my $flag = TRUE;
